@@ -46,7 +46,7 @@ typedef struct _GtrOpenTranPanelClass   GtrOpenTranPanelClass;
 
 struct _GtrOpenTranPanel
 {
-  GtkVBox parent_instance;
+  GtkBox parent_instance;
 
   /*< private > */
   GtrOpenTranPanelPrivate *priv;
@@ -54,12 +54,12 @@ struct _GtrOpenTranPanel
 
 struct _GtrOpenTranPanelClass
 {
-  GtkVBoxClass parent_class;
+  GtkBoxClass parent_class;
 };
 
 GType gtr_open_tran_panel_get_type (void) G_GNUC_CONST;
 
-GtkWidget *gtr_open_tran_panel_new (GtrWindow * window);
+GtkWidget *gtr_open_tran_panel_new (GtrTab * window);
 
 void _gtr_open_tran_panel_register_type (GTypeModule *type_module);
 
