@@ -132,8 +132,7 @@ gtr_po_parse_files_from_dialog (GtkWidget * dialog, GtrWindow * window)
    * We store latest directory
    */
   file = g_file_new_for_uri (po_files->data);
-  g_slist_foreach (po_files, (GFunc) g_free, NULL);
-  g_slist_free (po_files);
+  g_slist_free_full (po_files, g_free);
 
   parent = g_file_get_parent (file);
   g_object_unref (file);
@@ -148,8 +147,7 @@ gtr_po_parse_files_from_dialog (GtkWidget * dialog, GtrWindow * window)
    * Open the file via our centralized opening function.
    */
   load_file_list (window, (const GSList *) locations);
-  g_slist_foreach (locations, (GFunc) g_object_unref, NULL);
-  g_slist_free (locations);
+  g_slist_free_full (locations, g_object_unref);
 
   /*
    * Destroy the dialog 
@@ -308,7 +306,6 @@ gtr_save_file_as_dialog (GtkAction * action, GtrWindow * window)
   GtrPo *po;
   GFile *location;
   gchar *uri = NULL;
-  gboolean uri_set = FALSE;
 
   if (dialog != NULL)
     {
@@ -340,7 +337,7 @@ gtr_save_file_as_dialog (GtkAction * action, GtrWindow * window)
   g_object_unref (location);
 
   if (uri)
-    uri_set = gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (dialog), uri);
+    gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (dialog), uri);
 
   g_free (uri);
 
@@ -513,17 +510,9 @@ static void
 close_all_tabs (GtrWindow * window)
 {
   GtrNotebook *nb;
-  gint pages;
 
   nb = gtr_window_get_notebook (window);
-  pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb));
-
-  while (pages >= 0)
-    {
-      gtk_notebook_remove_page (GTK_NOTEBOOK (nb), pages);
-
-      pages--;
-    }
+  gtr_notebook_remove_all_pages (nb);
 
   //FIXME: This has to change once we add the close all documents menuitem
   gtk_widget_destroy (GTK_WIDGET (window));
