@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-toolbar-editor.c 929 2009-02-19 14:49:56Z friemann $
+ *  $Id$
  */
 
 #include "config.h"
@@ -37,8 +37,8 @@ static const GtkTargetEntry source_drag_types[] = {
 };
 
 
-static void egg_toolbar_editor_finalize (GObject * object);
-static void update_editor_sheet (EggToolbarEditor * editor);
+static void egg_toolbar_editor_finalize         (GObject *object);
+static void update_editor_sheet                 (EggToolbarEditor *editor);
 
 enum
 {
@@ -52,7 +52,7 @@ enum
   SIGNAL_HANDLER_ITEM_ADDED,
   SIGNAL_HANDLER_ITEM_REMOVED,
   SIGNAL_HANDLER_TOOLBAR_REMOVED,
-  SIGNAL_HANDLER_LIST_SIZE      /* Array size */
+  SIGNAL_HANDLER_LIST_SIZE  /* Array size */
 };
 
 #define EGG_TOOLBAR_EDITOR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EGG_TYPE_TOOLBAR_EDITOR, EggToolbarEditorPrivate))
@@ -64,17 +64,18 @@ struct EggToolbarEditorPrivate
 
   GtkWidget *table;
   GtkWidget *scrolled_window;
-  GList *actions_list;
-  GList *factory_list;
+  GList     *actions_list;
+  GList     *factory_list;
 
   /* These handlers need to be sanely disconnected when switching models */
-  gulong sig_handlers[SIGNAL_HANDLER_LIST_SIZE];
+  gulong     sig_handlers[SIGNAL_HANDLER_LIST_SIZE];
 };
 
-G_DEFINE_TYPE (EggToolbarEditor, egg_toolbar_editor, GTK_TYPE_VBOX);
+G_DEFINE_TYPE (EggToolbarEditor, egg_toolbar_editor, GTK_TYPE_BOX);
 
 static gint
-compare_items (gconstpointer a, gconstpointer b)
+compare_items (gconstpointer a,
+               gconstpointer b)
 {
   const GtkWidget *item1 = a;
   const GtkWidget *item2 = b;
@@ -88,7 +89,8 @@ compare_items (gconstpointer a, gconstpointer b)
 }
 
 static GtkAction *
-find_action (EggToolbarEditor * t, const char *name)
+find_action (EggToolbarEditor *t,
+	     const char       *name)
 {
   GList *l;
   GtkAction *action = NULL;
@@ -104,15 +106,15 @@ find_action (EggToolbarEditor * t, const char *name)
 
       tmp = gtk_action_group_get_action (GTK_ACTION_GROUP (l->data), name);
       if (tmp)
-        action = tmp;
+	action = tmp;
     }
 
   return action;
 }
 
 static void
-egg_toolbar_editor_set_ui_manager (EggToolbarEditor * t,
-                                   GtkUIManager * manager)
+egg_toolbar_editor_set_ui_manager (EggToolbarEditor *t,
+				   GtkUIManager     *manager)
 {
   g_return_if_fail (GTK_IS_UI_MANAGER (manager));
 
@@ -120,21 +122,24 @@ egg_toolbar_editor_set_ui_manager (EggToolbarEditor * t,
 }
 
 static void
-item_added_or_removed_cb (EggToolbarsModel * model,
-                          int tpos, int ipos, EggToolbarEditor * editor)
+item_added_or_removed_cb (EggToolbarsModel   *model,
+                          int                 tpos,
+                          int                 ipos,
+                          EggToolbarEditor   *editor)
 {
   update_editor_sheet (editor);
 }
 
 static void
-toolbar_removed_cb (EggToolbarsModel * model,
-                    int position, EggToolbarEditor * editor)
+toolbar_removed_cb (EggToolbarsModel   *model,
+	            int                 position,
+	            EggToolbarEditor   *editor)
 {
   update_editor_sheet (editor);
 }
 
 static void
-egg_toolbar_editor_disconnect_model (EggToolbarEditor * t)
+egg_toolbar_editor_disconnect_model (EggToolbarEditor *t)
 {
   EggToolbarEditorPrivate *priv = t->priv;
   EggToolbarsModel *model = priv->model;
@@ -147,18 +152,19 @@ egg_toolbar_editor_disconnect_model (EggToolbarEditor * t)
 
       if (handler != 0)
         {
-          if (g_signal_handler_is_connected (model, handler))
-            {
-              g_signal_handler_disconnect (model, handler);
-            }
+	  if (g_signal_handler_is_connected (model, handler))
+	    {
+	      g_signal_handler_disconnect (model, handler);
+	    }
 
-          priv->sig_handlers[i] = 0;
+	  priv->sig_handlers[i] = 0;
         }
     }
 }
 
 void
-egg_toolbar_editor_set_model (EggToolbarEditor * t, EggToolbarsModel * model)
+egg_toolbar_editor_set_model (EggToolbarEditor *t,
+			      EggToolbarsModel *model)
 {
   EggToolbarEditorPrivate *priv;
 
@@ -169,8 +175,7 @@ egg_toolbar_editor_set_model (EggToolbarEditor * t, EggToolbarsModel * model)
 
   if (priv->model)
     {
-      if (G_UNLIKELY (priv->model == model))
-        return;
+      if (G_UNLIKELY (priv->model == model)) return;
 
       egg_toolbar_editor_disconnect_model (t);
       g_object_unref (priv->model);
@@ -182,19 +187,20 @@ egg_toolbar_editor_set_model (EggToolbarEditor * t, EggToolbarsModel * model)
 
   priv->sig_handlers[SIGNAL_HANDLER_ITEM_ADDED] =
     g_signal_connect_object (model, "item_added",
-                             G_CALLBACK (item_added_or_removed_cb), t, 0);
+			     G_CALLBACK (item_added_or_removed_cb), t, 0);
   priv->sig_handlers[SIGNAL_HANDLER_ITEM_REMOVED] =
     g_signal_connect_object (model, "item_removed",
-                             G_CALLBACK (item_added_or_removed_cb), t, 0);
+			     G_CALLBACK (item_added_or_removed_cb), t, 0);
   priv->sig_handlers[SIGNAL_HANDLER_TOOLBAR_REMOVED] =
     g_signal_connect_object (model, "toolbar_removed",
-                             G_CALLBACK (toolbar_removed_cb), t, 0);
+			     G_CALLBACK (toolbar_removed_cb), t, 0);
 }
 
 static void
-egg_toolbar_editor_set_property (GObject * object,
-                                 guint prop_id,
-                                 const GValue * value, GParamSpec * pspec)
+egg_toolbar_editor_set_property (GObject      *object,
+				 guint         prop_id,
+				 const GValue *value,
+				 GParamSpec   *pspec)
 {
   EggToolbarEditor *t = EGG_TOOLBAR_EDITOR (object);
 
@@ -210,9 +216,10 @@ egg_toolbar_editor_set_property (GObject * object,
 }
 
 static void
-egg_toolbar_editor_get_property (GObject * object,
-                                 guint prop_id,
-                                 GValue * value, GParamSpec * pspec)
+egg_toolbar_editor_get_property (GObject    *object,
+				 guint       prop_id,
+				 GValue     *value,
+				 GParamSpec *pspec)
 {
   EggToolbarEditor *t = EGG_TOOLBAR_EDITOR (object);
 
@@ -228,7 +235,7 @@ egg_toolbar_editor_get_property (GObject * object,
 }
 
 static void
-egg_toolbar_editor_class_init (EggToolbarEditorClass * klass)
+egg_toolbar_editor_class_init (EggToolbarEditorClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
@@ -237,31 +244,27 @@ egg_toolbar_editor_class_init (EggToolbarEditorClass * klass)
   object_class->get_property = egg_toolbar_editor_get_property;
 
   g_object_class_install_property (object_class,
-                                   PROP_UI_MANAGER,
-                                   g_param_spec_object ("ui-manager",
-                                                        "UI-Manager",
-                                                        "UI Manager",
-                                                        GTK_TYPE_UI_MANAGER,
-                                                        G_PARAM_READWRITE |
-                                                        G_PARAM_STATIC_NAME |
-                                                        G_PARAM_STATIC_NICK |
-                                                        G_PARAM_STATIC_BLURB |
-                                                        G_PARAM_CONSTRUCT_ONLY));
-  g_object_class_install_property (object_class, PROP_TOOLBARS_MODEL,
-                                   g_param_spec_object ("model", "Model",
-                                                        "Toolbars Model",
-                                                        EGG_TYPE_TOOLBARS_MODEL,
-                                                        G_PARAM_READWRITE |
-                                                        G_PARAM_STATIC_NAME |
-                                                        G_PARAM_STATIC_NICK |
-                                                        G_PARAM_STATIC_BLURB |
-                                                        G_PARAM_CONSTRUCT));
+				   PROP_UI_MANAGER,
+				   g_param_spec_object ("ui-manager",
+							"UI-Manager",
+							"UI Manager",
+							GTK_TYPE_UI_MANAGER,
+							G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
+							G_PARAM_CONSTRUCT_ONLY));
+ g_object_class_install_property (object_class,
+				  PROP_TOOLBARS_MODEL,
+				  g_param_spec_object ("model",
+						       "Model",
+						       "Toolbars Model",
+						       EGG_TYPE_TOOLBARS_MODEL,
+						       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
+						       G_PARAM_CONSTRUCT));
 
   g_type_class_add_private (object_class, sizeof (EggToolbarEditorPrivate));
 }
 
 static void
-egg_toolbar_editor_finalize (GObject * object)
+egg_toolbar_editor_finalize (GObject *object)
 {
   EggToolbarEditor *editor = EGG_TOOLBAR_EDITOR (object);
 
@@ -283,42 +286,48 @@ egg_toolbar_editor_finalize (GObject * object)
 }
 
 GtkWidget *
-egg_toolbar_editor_new (GtkUIManager * manager, EggToolbarsModel * model)
+egg_toolbar_editor_new (GtkUIManager *manager,
+			EggToolbarsModel *model)
 {
   return GTK_WIDGET (g_object_new (EGG_TYPE_TOOLBAR_EDITOR,
-                                   "ui-manager", manager,
-                                   "model", model, NULL));
+				   "ui-manager", manager,
+				   "model", model,
+				   NULL));
 }
 
 static void
-drag_begin_cb (GtkWidget * widget, GdkDragContext * context)
+drag_begin_cb (GtkWidget          *widget,
+	       GdkDragContext     *context)
 {
   gtk_widget_hide (widget);
 }
 
 static void
-drag_end_cb (GtkWidget * widget, GdkDragContext * context)
+drag_end_cb (GtkWidget          *widget,
+	     GdkDragContext     *context)
 {
   gtk_widget_show (widget);
 }
 
 static void
-drag_data_get_cb (GtkWidget * widget,
-                  GdkDragContext * context,
-                  GtkSelectionData * selection_data,
-                  guint info, guint32 time, EggToolbarEditor * editor)
+drag_data_get_cb (GtkWidget          *widget,
+		  GdkDragContext     *context,
+		  GtkSelectionData   *selection_data,
+		  guint               info,
+		  guint32             time,
+		  EggToolbarEditor   *editor)
 {
   const char *target;
 
   target = g_object_get_data (G_OBJECT (widget), "egg-item-name");
   g_return_if_fail (target != NULL);
 
-  gtk_selection_data_set (selection_data, selection_data->target, 8,
-                          (const guchar *) target, strlen (target));
+  gtk_selection_data_set (selection_data, gtk_selection_data_get_target (selection_data), 8,
+			  (const guchar *) target, strlen (target));
 }
 
 static gchar *
-elide_underscores (const gchar * original)
+elide_underscores (const gchar *original)
 {
   gchar *q, *result;
   const gchar *p;
@@ -330,12 +339,12 @@ elide_underscores (const gchar * original)
   for (p = original; *p; p++)
     {
       if (!last_underscore && *p == '_')
-        last_underscore = TRUE;
+	last_underscore = TRUE;
       else
-        {
-          last_underscore = FALSE;
-          *q++ = *p;
-        }
+	{
+	  last_underscore = FALSE;
+	  *q++ = *p;
+	}
     }
 
   *q = '\0';
@@ -344,7 +353,7 @@ elide_underscores (const gchar * original)
 }
 
 static void
-set_drag_cursor (GtkWidget * widget)
+set_drag_cursor (GtkWidget *widget)
 {
   GdkCursor *cursor;
   GdkScreen *screen;
@@ -352,13 +361,17 @@ set_drag_cursor (GtkWidget * widget)
   screen = gtk_widget_get_screen (widget);
 
   cursor = gdk_cursor_new_for_display (gdk_screen_get_display (screen),
-                                       GDK_HAND2);
-  gdk_window_set_cursor (widget->window, cursor);
+				       GDK_HAND2);
+  gdk_window_set_cursor (gtk_widget_get_window (widget), cursor);
+#if GTK_CHECK_VERSION (3,0,0)
+  g_object_unref (cursor);
+#else
   gdk_cursor_unref (cursor);
+#endif
 }
 
 static void
-event_box_realize_cb (GtkWidget * widget, GtkImage * icon)
+event_box_realize_cb (GtkWidget *widget, GtkImage *icon)
 {
   GtkImageType type;
 
@@ -371,8 +384,8 @@ event_box_realize_cb (GtkWidget * widget, GtkImage * icon)
       GdkPixbuf *pixbuf;
 
       gtk_image_get_stock (icon, &stock_id, NULL);
-      pixbuf = gtk_widget_render_icon (widget, stock_id,
-                                       GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
+      pixbuf = gtk_widget_render_icon_pixbuf (widget, stock_id,
+                                              GTK_ICON_SIZE_LARGE_TOOLBAR);
       gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
       g_object_unref (pixbuf);
     }
@@ -392,10 +405,10 @@ event_box_realize_cb (GtkWidget * widget, GtkImage * icon)
 
       if (!gtk_icon_size_lookup_for_settings (settings,
                                               GTK_ICON_SIZE_LARGE_TOOLBAR,
-                                              &width, &height))
+					      &width, &height))
         {
-          width = height = 24;
-        }
+	  width = height = 24;
+	}
 
       pixbuf = gtk_icon_theme_load_icon (icon_theme, icon_name,
                                          MIN (width, height), 0, NULL);
@@ -414,9 +427,10 @@ event_box_realize_cb (GtkWidget * widget, GtkImage * icon)
 }
 
 static GtkWidget *
-editor_create_item (EggToolbarEditor * editor,
-                    GtkImage * icon,
-                    const char *label_text, GdkDragAction action)
+editor_create_item (EggToolbarEditor *editor,
+		    GtkImage	     *icon,
+		    const char       *label_text,
+		    GdkDragAction     action)
 {
   GtkWidget *event_box;
   GtkWidget *vbox;
@@ -427,20 +441,19 @@ editor_create_item (EggToolbarEditor * editor,
   gtk_event_box_set_visible_window (GTK_EVENT_BOX (event_box), FALSE);
   gtk_widget_show (event_box);
   gtk_drag_source_set (event_box,
-                       GDK_BUTTON1_MASK,
-                       source_drag_types, G_N_ELEMENTS (source_drag_types),
-                       action);
-  g_signal_connect (event_box, "drag_data_get", G_CALLBACK (drag_data_get_cb),
-                    editor);
+		       GDK_BUTTON1_MASK,
+		       source_drag_types, G_N_ELEMENTS (source_drag_types), action);
+  g_signal_connect (event_box, "drag_data_get",
+		    G_CALLBACK (drag_data_get_cb), editor);
   g_signal_connect_after (event_box, "realize",
-                          G_CALLBACK (event_box_realize_cb), icon);
+		          G_CALLBACK (event_box_realize_cb), icon);
 
   if (action == GDK_ACTION_MOVE)
     {
       g_signal_connect (event_box, "drag_begin",
-                        G_CALLBACK (drag_begin_cb), NULL);
+		        G_CALLBACK (drag_begin_cb), NULL);
       g_signal_connect (event_box, "drag_end",
-                        G_CALLBACK (drag_end_cb), NULL);
+		        G_CALLBACK (drag_end_cb), NULL);
     }
 
   vbox = gtk_vbox_new (0, FALSE);
@@ -459,8 +472,9 @@ editor_create_item (EggToolbarEditor * editor,
 }
 
 static GtkWidget *
-editor_create_item_from_name (EggToolbarEditor * editor,
-                              const char *name, GdkDragAction drag_action)
+editor_create_item_from_name (EggToolbarEditor *editor,
+                              const char *      name,
+                              GdkDragAction     drag_action)
 {
   GtkWidget *item;
   const char *item_name;
@@ -489,12 +503,14 @@ editor_create_item_from_name (EggToolbarEditor * editor,
 
       g_object_get (action,
                     "icon-name", &icon_name,
-                    "stock-id", &stock_id, "short-label", &short_label, NULL);
+                    "stock-id", &stock_id,
+		    "short-label", &short_label,
+		    NULL);
 
       /* This is a workaround to catch named icons. */
       if (icon_name)
         icon = gtk_image_new_from_icon_name (icon_name,
-                                             GTK_ICON_SIZE_LARGE_TOOLBAR);
+	                                     GTK_ICON_SIZE_LARGE_TOOLBAR);
       else
         icon = gtk_image_new_from_stock (stock_id ? stock_id : GTK_STOCK_DND,
                                          GTK_ICON_SIZE_LARGE_TOOLBAR);
@@ -518,7 +534,7 @@ editor_create_item_from_name (EggToolbarEditor * editor,
 }
 
 static gint
-append_table (GtkTable * table, GList * items, gint y, gint width)
+append_table (GtkTable *table, GList *items, gint y, gint width)
 {
   if (items != NULL)
     {
@@ -537,8 +553,7 @@ append_table (GtkTable * table, GList * items, gint y, gint width)
           gtk_widget_show (alignment);
           gtk_widget_show (item);
 
-          gtk_table_attach_defaults (table, alignment, 0, width, y - 1,
-                                     y + 1);
+          gtk_table_attach_defaults (table, alignment, 0, width, y-1, y+1);
         }
 
       for (; items != NULL; items = items->next)
@@ -554,7 +569,7 @@ append_table (GtkTable * table, GList * items, gint y, gint width)
               x = 0;
               y++;
             }
-          gtk_table_attach_defaults (table, alignment, x, x + 1, y, y + 1);
+          gtk_table_attach_defaults (table, alignment, x, x+1, y, y+1);
           x++;
         }
 
@@ -564,7 +579,7 @@ append_table (GtkTable * table, GList * items, gint y, gint width)
 }
 
 static void
-update_editor_sheet (EggToolbarEditor * editor)
+update_editor_sheet (EggToolbarEditor *editor)
 {
   gint y;
   GPtrArray *items;
@@ -581,7 +596,7 @@ update_editor_sheet (EggToolbarEditor * editor)
   gtk_table_set_row_spacings (GTK_TABLE (table), 24);
   gtk_widget_show (table);
   gtk_drag_dest_set (table, GTK_DEST_DEFAULT_ALL,
-                     dest_drag_types, G_N_ELEMENTS (dest_drag_types),
+		     dest_drag_types, G_N_ELEMENTS (dest_drag_types),
                      GDK_ACTION_MOVE | GDK_ACTION_COPY);
 
   /* Build two lists of items (one for copying, one for moving). */
@@ -620,11 +635,11 @@ update_editor_sheet (EggToolbarEditor * editor)
   g_ptr_array_free (items, TRUE);
 
   /* Delete old table. */
-  viewport = GTK_BIN (editor->priv->scrolled_window)->child;
+  viewport = gtk_bin_get_child (GTK_BIN (editor->priv->scrolled_window));
   if (viewport)
     {
       gtk_container_remove (GTK_CONTAINER (viewport),
-                            GTK_BIN (viewport)->child);
+                            gtk_bin_get_child (GTK_BIN (viewport)));
     }
 
   /* Add table to window. */
@@ -634,7 +649,7 @@ update_editor_sheet (EggToolbarEditor * editor)
 }
 
 static void
-setup_editor (EggToolbarEditor * editor)
+setup_editor (EggToolbarEditor *editor)
 {
   GtkWidget *scrolled_window;
 
@@ -643,17 +658,21 @@ setup_editor (EggToolbarEditor * editor)
   editor->priv->scrolled_window = scrolled_window;
   gtk_widget_show (scrolled_window);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_box_pack_start (GTK_BOX (editor), scrolled_window, TRUE, TRUE, 0);
 }
 
 static void
-egg_toolbar_editor_init (EggToolbarEditor * t)
+egg_toolbar_editor_init (EggToolbarEditor *t)
 {
   t->priv = EGG_TOOLBAR_EDITOR_GET_PRIVATE (t);
 
   t->priv->manager = NULL;
   t->priv->actions_list = NULL;
 
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (t),
+                                  GTK_ORIENTATION_VERTICAL);
+
   setup_editor (t);
 }
+
